<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en_US">
<context>
    <name>AudioPreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="71"/>
        <source>Artist:</source>
        <translation>Artist:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="83"/>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="108"/>
        <source>Duration:</source>
        <translation>Duration:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="123"/>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="135"/>
        <source>Location:</source>
        <translation>Location:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="149"/>
        <source>Time modified:</source>
        <translation>Time modified:</translation>
    </message>
</context>
<context>
    <name>BestMatchWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/bestmatchwidget.cpp" line="38"/>
        <source>Best match</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CustomWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/customwidget.cpp" line="42"/>
        <source>Custom search</source>
        <translation>Custom search</translation>
    </message>
</context>
<context>
    <name>DdeGrandSearchDockPlugin</name>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="57"/>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="100"/>
        <source>Grand Search</source>
        <translation>Grand Search</translation>
    </message>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="163"/>
        <source>Search settings</source>
        <translation>Search settings</translation>
    </message>
</context>
<context>
    <name>EntranceWidget</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="241"/>
        <source>Search</source>
        <translation>Search</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="242"/>
        <source>What would you like to search for?</source>
        <translation>What would you like to search for?</translation>
    </message>
</context>
<context>
    <name>EntranceWidgetPrivate</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="94"/>
        <source>Cut</source>
        <translation>Cut</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="98"/>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="102"/>
        <source>Paste</source>
        <translation>Paste</translation>
    </message>
</context>
<context>
    <name>GeneralPreviewPlugin</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="208"/>
        <source>Location:</source>
        <translation>Location:</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="219"/>
        <source>Time modified:</source>
        <translation>Time modified:</translation>
    </message>
</context>
<context>
    <name>GeneralToolBar</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="85"/>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="90"/>
        <source>Open Path</source>
        <translation>Open Path</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="95"/>
        <source>Copy Path</source>
        <translation>Copy Path</translation>
    </message>
</context>
<context>
    <name>GroupWidget</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="260"/>
        <source>More</source>
        <translation>More</translation>
    </message>
</context>
<context>
    <name>ImagePreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="67"/>
        <source>Dimensions:</source>
        <translation>Dimensions:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="83"/>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="98"/>
        <source>Size:</source>
        <translation>Size:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="110"/>
        <source>Location:</source>
        <translation>Location:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="124"/>
        <source>Time modified:</source>
        <translation>Time modified:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/grand-search/gui/mainwindow.cpp" line="224"/>
        <source>No search results</source>
        <translation>No search results</translation>
    </message>
</context>
<context>
    <name>PlanWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="43"/>
        <source>Search experience program</source>
        <translation>Search experience program</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="51"/>
        <source>Join search experience program</source>
        <translation>Join search experience program</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="64"/>
        <source>Joining the search experience program means that you grant and authorize us to collect the information of your device and system, file icons, content and properties, applications and their configurations. If you refuse our collection and use of the aforementioned information, do not join the program.</source>
        <translation>Joining the search experience program means that you grant and authorize us to collect the information of your device and system, file icons, content and properties, applications and their configurations. If you refuse our collection and use of the aforementioned information, do not join the program.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="73"/>
        <source>To know more about the management of your data, please refer to the UnionTech Software Privacy Policy (</source>
        <translation>To know more about the management of your data, please refer to the UnionTech Software Privacy Policy (</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="75"/>
        <source>https://www.uniontech.com/agreement/privacy-en</source>
        <translation>https://www.uniontech.com/agreement/privacy-en</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="76"/>
        <source>https://www.deepin.org/en/agreement/privacy/</source>
        <translation>https://www.deepin.org/en/agreement/privacy/</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="78"/>
        <source>).</source>
        <translation>).</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="41"/>
        <source>Best match</source>
        <translation>Best match</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="42"/>
        <source>Applications</source>
        <translation>Applications</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="43"/>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="44"/>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="45"/>
        <source>Music</source>
        <translation>Music</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="46"/>
        <source>Pictures</source>
        <translation>Pictures</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="47"/>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="48"/>
        <source>Folders</source>
        <translation>Folders</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="49"/>
        <source>Files</source>
        <translation>Files</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="50"/>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="38"/>
        <source>Dimensions:</source>
        <translation>Dimensions:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="39"/>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="40"/>
        <source>Size:</source>
        <translation>Size:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="41"/>
        <source>Duration:</source>
        <translation>Duration:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="42"/>
        <source>Location:</source>
        <translation>Location:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="43"/>
        <source>Time modified:</source>
        <translation>Time modified:</translation>
    </message>
    <message>
        <location filename="../src/grand-search-daemon/searcher/file/filesearchutils.cpp" line="215"/>
        <source>modified</source>
        <translation>modified</translation>
    </message>
</context>
<context>
    <name>ScopeWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/scopewidget.cpp" line="44"/>
        <source>Search contents</source>
        <translation>Search contents</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="48"/>
        <source>Default search engine</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="56"/>
        <source>Search for keywords by the default search engine.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="72"/>
        <source>Default search engine is</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="81"/>
        <source>Google</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="82"/>
        <source>Baidu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="83"/>
        <source>Bing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="84"/>
        <source>Yahoo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="85"/>
        <source>360</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="86"/>
        <source>Sogou</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StaticTextWorker</name>
    <message>
        <location filename="../src/grand-search-daemon/searcher/web/statictextworker.cpp" line="67"/>
        <source>Search for &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TailerWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="33"/>
        <source>Tailer settings</source>
        <translation>Tailer settings</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="43"/>
        <source>It is displayed at the end of search results for better identification and distinction of items with duplicate names.</source>
        <translation>It is displayed at the end of search results for better identification and distinction of items with duplicate names.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="56"/>
        <source>Parent directory</source>
        <translation>Parent directory</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="58"/>
        <source>Time modified</source>
        <translation>Time modified</translation>
    </message>
</context>
</TS>